/*-
 * ============LICENSE_START=======================================================
 * sdc-distribution-client
 * ================================================================================
 * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ============LICENSE_END=========================================================
 */

package org.openecomp.sdc.api.notification;

import java.util.List;

public interface IResourceInstance {
	/**Logical Resource Instance Name. <br>
	 * Unique Identifier of  the instance of the  specific resource in the service context.**/
	String getResourceInstanceName();
	
	/**resource name */
	String getResourceName();
	
	/**resource version */
	String getResourceVersion();

	/**Resource Type (For Example: VF (Virtual Function) - A subsystem in a service, it can include one or more VFCs. This is what NFV spec refers as VNF.)**/
	String getResourceType();
	
	/**Global UUID of the resource that specific artifact belongs to.<br>
	It is generated by SDC per each resource version.<br>
	Generated UUID is compliant with RFC 4122. It is a 128-bit value formatted into blocks of hexadecimal digits separated by a hyphen ("-"). <br>
	Ex.: AA97B177-9383-4934-8543-0F91A7A02836**/
	String getResourceUUID();

	/**List of resource instance deployment artifacts.**/
	List<IArtifactInfo> getArtifacts();
	
	/**Invariant (constant) resource UUID generated on resource creation.**/
	String getResourceInvariantUUID();
	
	/**This UUID is unique in the context of the service.<br>
	It is regenerated whenever a designer makes changes to the resource instance.<br>
	A change may be updating HEAT value, updating property value or name of the resource instance.<br>
	It is also regenerated when an artifact is uploaded to the resource instance.**/
	String getResourceCustomizationUUID();
	
	/**The category of the resource model.<br>
	E.g. "Application L4+".**/
	String getCategory();
	
	/**The subcategory of the resource model.<br>
	E.g. "Call Control"**/
	String getSubcategory();

}
